==> haskell-success-0.2.6-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-6H05XuLjWE8Dnx302Qio3i
key: success-0.2.6-6H05XuLjWE8Dnx302Qio3i
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Success.Pure Success.Impure
abi: b42d957a2c5886f80c443bffc99a9088
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/success-0.2.6
hs-libraries: HSsuccess-0.2.6-6H05XuLjWE8Dnx302Qio3i
depends:
    base-4.9.1.0 monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-931TaAlnoJF1jOr7rTARy8
key: success-0.2.6-931TaAlnoJF1jOr7rTARy8
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Success.Pure Success.Impure
abi: 1f66496a75df46b910137692beaf7a97
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/success-0.2.6
hs-libraries: HSsuccess-0.2.6-931TaAlnoJF1jOr7rTARy8
depends:
    base-4.9.1.0 monad-control-1.0.2.2-FLdbJMBsCl8Hxe7Woti7SW
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
